/** @file SkChunkLoader.h
 SodaKit - Download rows in chunks via method=getRows
 
 Copyright (c) 2012 Edgemoor. All rights reserved.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
 http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

#import <Foundation/Foundation.h>

//! State of SkChunkLoader 
typedef enum {
    eSkChunkLoaderState_INVALID     =   0,  //!< Not set or Invalid
    eSkChunkLoaderState_Pending     =   1,  //!< Object created, but request not begun
    eSkChunkLoaderState_Running     =   2,  //!< RKObjectLoader in progress
    eSkChunkLoaderState_DoneFail    =  10,  //!< RKObjectLoader ended with error
    eSkChunkLoaderState_DoneSuccess =  11,  //!< RKObjectLoader complete with success
} eSkChunkLoaderState;

//!  SodaKit - Download rows in chunks via method=getRows
@interface SkChunkLoader : NSObject <RKObjectLoaderDelegate>

- (id)          initWithUserInfo: (NSObject*) userInfo;

@property (readonly)    NSObject*           userInfo; //!< Optional user supplied info
@property (readonly)    RKObjectLoader*     loader;   //!< RKObjectLoader for request
@property (readonly)    eSkChunkLoaderState eState;   //!< State of SkChunkLoader

+ (NSString*)       notifyName;

@end
