/** @file SkObjectManager.m
 SodaKit - Extend RKObjectManager to convert SODA Rest data into standard JSON format
 
 Copyright (c) 2012 Edgemoor. All rights reserved.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
 http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

#import "SkObjectManager.h"

@implementation SkObjectManager

#pragma mark - public methods

//! Facade for RKObjectManager loadObjectsAtResourcePath, setting SkChunkLoader as delegate
- (SkChunkLoader*)  loadObjectsAtResourcePath: (NSString*)        resourcePath_
                                      mapping: (RKObjectMapping*) objectMapping_ {
    return [self loadObjectsAtResourcePath: resourcePath_ mapping: objectMapping_ userInfo: nil];
}
//! Facade for RKObjectManager loadObjectsAtResourcePath, setting SkChunkLoader as delegate
- (SkChunkLoader*)  loadObjectsAtResourcePath: (NSString*)        resourcePath_
                                      mapping: (RKObjectMapping*) objectMapping_ 
                                     userInfo: (NSObject*)        userInfo_ {
    SkChunkLoader* chunkLoader = [[SkChunkLoader alloc] initWithUserInfo: userInfo_];
    self.client.cachePolicy = RKRequestCachePolicyNone;
    self.client.requestQueue.showsNetworkActivityIndicatorWhenBusy = YES;
    [super loadObjectsAtResourcePath: resourcePath_ 
                          usingBlock: ^(RKObjectLoader* loader_) {
        loader_.delegate      = chunkLoader;
        loader_.objectMapping = objectMapping_;
    }];
    return chunkLoader;
}
@end
